## Discussion: En route vers une intelligence artificielle durable

## Agenda

- La Déclaration de Montréal
- Les objectifs de développement durable de l'ONU
- Quelques normes pouvant servir d'inspiration à la pratique
  - ISO 22989:2022 - Technologies de l'information — Intelligence artificielle — Concepts et terminologie relatifs à l'intelligence artificielle
  - ISO 27001:2022 - Sécurité de l'information, cybersécurité et protection de la vie privée — Systèmes de management de la sécurité de l'information — Exigences
  - ISO 27002:2022 - Sécurité de l'information, cybersécurité et protection de la vie privée — Mesures de sécurité de l'information
  - ISO 27701:2019 - Techniques de sécurité — Extension d'ISO/IEC 27001 et ISO/IEC 27002 au management de la protection de la vie privée — Exigences et lignes directrices
  - ISO 53002:2024 - Lignes directrices pour contribuer aux objectifs de développement durable (ODD) des Nations Unies
  - Normes IEEE de la série 7000 - Autonomous and Intelligent Systems
- Discussions
  - préoccupations
  - bonnes pratiques à explorer

## La Déclaration de Montréal

Titre complet: La Déclaration de Montréal pour un développement responsable de l'intelligence artificielle

1. Cadre éthique pour développement et déploiement de l'IA
2. Orienter la transition numérique
3. Espace de dialogue pour développement inclusif, équitable et écologiquement soutenable

10 principes:

* 🔥 Bien-être
* 🛵 Respect de l’autonomie
* 🔒 Protection de l'intimité et de la vie privée
* 🤝 Solidarité
* 🗳 Participation démocratique
* ⚖️ Équité
* 🌈 Inclusion de la diversité
* 🤔 Prudence
* 📜 Responsabilité
* 🌍 Développement soutenable

<https://declarationmontreal-iaresponsable.com/la-declaration/>

![ishare-1742356297-brave browser.PNG](images/ishare-1742356297-brave%20browser.PNG)

Je suis signataire !

![ishare-1742356092-brave browser.PNG](images/ishare-1742356092-brave%20browser.PNG)

## Les objectifs de développement durable de l'ONU

17 objectifs que les Nations Unies se sont données pour 2030.

![poster_odd.png](images/poster_odd.png)

<https://www.un.org/sustainabledevelopment/fr/objectifs-de-developpement-durable/>

## Pourquoi des normes ?

![pourquoi-des-normes-ingenieurs-tristes.jpeg](images/pourquoi-des-normes-ingenieurs-tristes.jpeg)

- Parce qu'il se passe absolument n'importe quoi en ce moment dans le domaine de l'IA. Nous avons besoin de repères et de critères de qualité.

![ishare-1742397002-brave browser.PNG](images/ishare-1742397002-brave%20browser.PNG)

- Parce que l'égo prend souvent le dessus sur la collaboration. Chaque organisation veut avoir son propre code d'éthique en IA pour bien paraître.
  - Source: <https://inventory.algorithmwatch.org/>

![ishare-1742397211-brave browser.PNG](images/ishare-1742397211-brave%20browser.PNG)

- Parce que l'intelligence artificielle, ça va bien au dela de l'IA générative.
  - Source: <https://jevalide.ca/2023/09/08/les-types-dintelligence-artificielle/>

- Pour pouvoir se comprendre:
  - Les normes offrent un vocabulaire commun issu d'un consensus international.

## Quelques normes pouvant servir d'inspiration à la pratique

### ISO 22989:2022 - Concepts et terminologie relatifs à l'intelligence artificielle

#### Quelques définitions d'intérêt

> Système d'IA (3.1.4): système technique qui génère des sorties telles que du contenu, des prévisions, des recommandations ou des décisions pour un ensemble donné d'objectifs définis par l'homme.

> Intelligence artificielle générale (3.1.14) : type de système d'IA (3.1.4) qui traite un large éventail de tâches (3.1.35) en affichant un niveau de performances satisfaisant.

> Biais (3.5.4): différence systématique de traitement de certains objets, de certaines personnes ou de certains groupes par rapport à d'autres.

> Prévisibilité (3.5.8): propriété d'un système d'IA (3.1.4) qui permet aux parties prenantes (3.5.13) de formuler des hypothèses fiables au sujet de la sortie.

> Partie prenante (3.5.13): toute personne, groupe ou organisation pouvant affecter, être affecté(e) ou se sentir lui-même/elle-même affecté(e) par une décision ou une activité.

> Génération automatique de texte: tâche (3.1.35) consistant à convertir des données contenant de la sémantique en langage naturel.

#### Table des matières de la norme

1. Domaine d'application
2. Références normatives
3. Termes et définitions
4. Abréviations
5. Concepts de l'IA
6. Cycle de vie de système d'IA
7. Aperçu fonctionnel du système d'IA
8. Écosystème de l'IA
9. Domaines de l'IA
10. Applications des systèmes d'IA

![table-matieres-22989-2022-1.png](images/table-matieres-22989-2022-1.png)
![table-matieres-22989-2022-2.png](images/table-matieres-22989-2022-2.png)
![table-matieres-22989-2022-3.png](images/table-matieres-22989-2022-3.png)
![table-matieres-22989-2022-4.png](images/table-matieres-22989-2022-4.png)

Norme gratuite ! <https://www.iso.org/fr/standard/74296.html>

### ISO 27001:2022 et ISO 27002:2022: Systèmes de management de la sécurité de l'information — Exigences, Mesures de sécurité de l'information

Ce sont les deux normes principales en sécurité de l'information (dont fait partie la cybersécurité)

La norme ISO 27001:2022 propose la mise en place de 93 mesures de contrôle qui sont définies en annexe. La norme ISO 27002:2022 propose des moyens de mettre en oeuvre ces contrôles.

Ils sont regroupés en 4 principales catégories:

- Organisationnel
- Personnel (RH)
- Physiques
- Technologiques

### ISO 27701:2019: Techniques de sécurité — Extension d'ISO/IEC 27001 et ISO/IEC 27002 au management de la protection de la vie privée — Exigences et lignes directrices

### ISO 53002:2024: Lignes directrices pour contribuer aux objectifs de développement durable (ODD) des Nations Unies

#### Points clés pour les organisations (5.1) :

1. Identifier les parties prenantes pertinentes pour optimiser les contributions aux ODD.
2. Déterminer les exigences, besoins et attentes de ces parties prenantes.
3. Décider quelles exigences seront traitées et comment.
4. Établir un processus pour engager les parties prenantes afin de comprendre :
   - Les impacts réels et attendus des activités de l'organisation
   - L'importance relative des différents impacts et enjeux de développement durable
   - Les besoins et attentes des parties prenantes
   - Les conséquences si les impacts attendus ne sont pas atteints
   - Leur tolérance aux impacts inattendus

Groupes sous-reconnus et vulnérables à considérer :

- Femmes et filles
- Personnes en situation de handicap
- Enfants
- Peuples autochtones
- Migrants, travailleurs migrants et leurs familles
- Personnes discriminées sur la base de leur ascendance (y compris la caste) ou de leur race
- Autres groupes vulnérables (ex : personnes âgées, déplacées, pauvres, analphabètes, minorités ou groupes religieux)

#### Parties prenantes (5.2, 5.3)

| Parties prenantes subissant les impacts | Parties prenantes contribuant aux impacts |
|-----------------------------------------|-------------------------------------------|
| Environnement et biodiversité           | Gouvernements                             |
| Travailleurs                            | ONG et organisations philanthropiques     |
| Communautés locales et élargies         | Régulateurs                               |
| Groupes vulnérables                     | Associations professionnelles             |
| Générations futures                     | Entreprises et industries                 |
| Clients et consommateurs                | Fournisseurs et distributeurs             |
| Société                                 | Propriétaires, investisseurs              |
| Fournisseurs                            | Organisations parentes ou filiales        |
| Propriétaires et investisseurs          | Pairs et concurrents                      |
|                                         | Milieu académique et chercheurs           |

#### Pratiques d'affaires responsables (7.2) :

- Responsabilité : Être redevable envers les parties prenantes, assumer la responsabilité des impacts.
- Transparence : Fournir des informations pertinentes, précises et complètes sur les activités liées aux ODD.
- Comportement éthique : Agir avec honnêteté, équité et intégrité, lutter contre la corruption.
- Respect des besoins des parties prenantes : Engager et considérer les perspectives des parties prenantes.
- Respect des normes internationales : Appliquer les meilleures pratiques, surtout en l'absence de réglementations locales adéquates.
- Respect des droits humains : Protéger et promouvoir les droits humains, éviter toute complicité d'abus.
- Ne laisser personne de côté : Promouvoir l'inclusion, réduire les inégalités, autonomiser les femmes.

#### Innovation (7.3)

f) Données et analyses : Innovations dans la collecte, l'analyse et la diffusion des données (ex : mégadonnées, IA, Internet des objets, technologie satellitaire) pour mesurer les impacts, identifier les tendances et allouer les ressources efficacement.

g) Stratégies de communication : Utilisation de plateformes numériques et médias sociaux pour amplifier les messages.

Norme gratuite ! <https://www.iso.org/fr/standard/87945.html>

### Normes IEEE de la série 7000 - Autonomous and Intelligent Systems

https://standards.ieee.org/initiatives/autonomous-intelligence-systems/

* [IEEE 7000: Standard Model Process for Addressing Ethical Concerns during System Design](https://standards.ieee.org/ieee/7000/6781/)
* [IEEE 7001: Standard for Transparency of Autonomous Systems](https://standards.ieee.org/ieee/7001/6929/)
* [IEEE 7002: Standard for Data Privacy Process](https://standards.ieee.org/ieee/7002/6898/)
* [IEEE 7003: Standard for Algorithmic Bias Considerations](https://standards.ieee.org/ieee/7003/11357/)
* [IEEE 7005: Standard for Transparent Employer Data Governance](https://standards.ieee.org/ieee/7005/7014/)
* [IEEE 7007: Ontological Standard for Ethically Driven Robotics and Automation Systems](https://standards.ieee.org/ieee/7007/7070/)
* [IEEE 7009: Standard for Fail-Safe Design of Autonomous and Semi-Autonomous Systems](https://standards.ieee.org/ieee/7009/7096/)
* [IEEE 7010: Recommended Practice for Assessing the Impact of Autonomous and Intelligent Systems on Human Well-Being](https://standards.ieee.org/ieee/7010/7718/)
* [IEEE 7014: Standard for Ethical Considerations in Emulated Empathy in Autonomous and Intelligent Systems](https://standards.ieee.org/ieee/7014/7648/)

Norme pour les services numériques concernant les enfants :

* [IEEE 2089: Standard for an Age Appropriate Digital Services Framework Based on the 5Rights Principles for Children](https://standards.ieee.org/ieee/2089/7633/)

Toutes ces normes sont disponibles gratuitement sur le site de IEEE GET: <https://ieeexplore.ieee.org/browse/standards/get-program/page/series?id=93>

5Rights Foundation: <https://5rightsfoundation.com/>

## Discussion: préoccupations

- Quelles sont les principales préoccupations sur l'utilisation de l'IA dans les TPO ?

## Discussion: bonnes pratiques

- Quelles sont les bonnes pratiques qui sont réalistes à adopter pour utiliser de l'IA dans les TPO ?

## Contacts

* [François Pelletier](mailto:francois@normestpo.ca)
* [Marc Taillefer](mailto:marc@normestpo.ca)

Normes TPO: Faire la promotion des normes pour les très petites organisations
- [normestpo.ca](https://normestpo.ca)

## Autres références

* [G7 reporting framework – Hiroshima AI Process](https://transparency.oecd.ai/)
* [OCDE - Thèmes - Intelligence artificielle](https://www.oecd.org/fr/themes/intelligence-artificielle.html)

Consultation en IA responsable
- [jevalide.ca](https://jevalide.ca)
